// Set up the dimensions of the map
const width = 800;
const height = 500;

// Create an SVG element to hold the map
const svg = d3.select("#map")
  .append("svg")
  .attr("width", width)
  .attr("height", height);

// Load the dataset from the CSV file
d3.csv("world_data.csv").then(function(data) {
  // Convert population values to numbers
  data.forEach(function(d) {
    d.population = +d.population;
  });

 const colorScale = d3.scaleQuantize()
  .domain(d3.extent(data, d => d.population)) // Use d3.extent to get the min and max population values
  .range(d3.schemeBlues[5]);

  // Define a projection for the map
  const projection = d3.geoNaturalEarth1()
    .translate([width / 2, height / 2])
    .scale(150);

  // Create a path generator based on the projection
  const path = d3.geoPath()
    .projection(projection);

  // Load the world map data in GeoJSON format
  d3.json("https://raw.githubusercontent.com/nvkelso/natural-earth-vector/master/geojson/ne_110m_admin_0_countries.geojson").then(function(world) {
    // Draw the map
    svg.selectAll("path")
      .data(world.features)
      .enter()
      .append("path")
      .attr("d", path)
      .attr("fill", function(d) {
        // Find the corresponding data value for each country
      	console.log(d)
        const countryData = data.find(country => country.country == d.properties.NAME);
      	console.log(countryData)
        if (countryData) {
          return colorScale(countryData.population);
        }
        return "black"; // Default color for countries with no data
      });
  });
});
